#
# File: acinclude.m4
# Auth: Christian Hansen (chansen@cs.umd.edu)
#       University of Maryland, College Park
# Desc: Tests for PVM, MPI, XML, and HDF
# Date: 01/28/04
#

AC_DEFUN([AC_CHECK_PVM_WITH_C], [
AC_MSG_CHECKING(for PVM C headers)
CPPFLAGS="$CPPFLAGS -I$PVM_ROOT/include"
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([#include <pvm3.h>]), 
  AC_MSG_RESULT(found), 
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for PVM C libraries)
LDFLAGS="$LDFLAGS -L$PVM_ROOT/lib/$PVM_ARCH"
SAVE="$LIBS"
LIBS="-lgpvm3 -lpvm3 $LIBS"
AC_LINK_IFELSE(AC_LANG_PROGRAM([#include <pvm3.h>], [
	int p; 
	p = pvm_parent(); 
	pvm_exit();
]), 
  AC_MSG_RESULT(found), 
  AC_MSG_FAILURE(failed!))
LIBS="$SAVE"
])

AC_DEFUN([AC_CHECK_PVM_WITH_FORTRAN], [
AC_LANG_PUSH(Fortran 77)
AC_MSG_CHECKING(for PVM Fortran headers)
FFLAGS="$FFLAGS -I$PVM_ROOT/include"
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([], [
	include 'fpvm3.h'
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for PVM Fortran libraries)
LDFLAGS="$LDFLAGS -L$PVM_ROOT/lib/$PVM_ARCH"
SAVE="$LIBS"
LIBS="-lfpvm3 -lgpvm3 -lpvm3 $LIBS"
AC_LINK_IFELSE(AC_LANG_PROGRAM([], [
	include 'fpvm3.h'
	integer p
	call pvmfparent(p)
	call pvmfexit(p)
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
LIBS="$SAVE"
AC_LANG_POP(Fortran 77)
])

AC_DEFUN([AC_CHECK_MPI_WITH_C], [
AC_MSG_CHECKING(for MPI C headers)
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([#include <mpi.h>]), 
  AC_MSG_RESULT(found), 
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for MPI C libraries)
AC_LINK_IFELSE(AC_LANG_PROGRAM([#include <mpi.h>], [
	int argc;
	char** argv;
	MPI_Init(&argc, &argv);
	MPI_Finalize();
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
])

AC_DEFUN([AC_CHECK_MPI_WITH_FORTRAN], [
AC_LANG_PUSH(Fortran 77)
AC_MSG_CHECKING(for MPI Fortran headers)
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([], [
	include 'mpif.h'
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for MPI Fortran libraries)
AC_LINK_IFELSE(AC_LANG_PROGRAM([], [
	include 'mpif.h'
	integer ierror
	call MPI_INIT(ierror)
	call MPI_FINALIZE(ierror)
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
AC_LANG_POP(Fortran 77)
])

AC_DEFUN([AC_CHECK_XML], [
AC_MSG_CHECKING(for XML headers)
if test x$1 != xyes; then
  CPPFLAGS="$CPPFLAGS -I$1/include/libxml2"
else
  CPPFLAGS="$CPPFLAGS -I/usr/include/libxml2"
fi
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([
	#include <libxml/xmlmemory.h> 
	#include <libxml/parser.h>
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for XML libraries)
if test x$1 != xyes; then
  LDFLAGS="$LDFLAGS -L$1/lib"
fi
SAVE="$LIBS"
LIBS="-lxml2 $LIBS"
AC_LINK_IFELSE(AC_LANG_PROGRAM([
	#include <libxml/xmlmemory.h> 
	#include <libxml/parser.h>
], [
	char** argv;
	xmlDocPtr doc;
	doc = xmlParseFile(*(argv+1));
	xmlFreeDoc(doc);
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
LIBS="$SAVE"
])

AC_DEFUN([AC_CHECK_HDF], [
AC_MSG_CHECKING(for HDF headers)
if test x$1 != xyes; then
  CPPFLAGS="$CPPFLAGS -I$1/include"
fi
AC_COMPILE_IFELSE(AC_LANG_PROGRAM([#include <hdf5.h>]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
AC_MSG_CHECKING(for HDF libraries)
if test x$1 != xyes; then
  LDFLAGS="$LDFLAGS -L$1/lib"
fi
SAVE="$LIBS"
LIBS="-lhdf5 -lz $LIBS"
AC_LINK_IFELSE(AC_LANG_PROGRAM([#include <hdf5.h>], [
	char** argv;
	hid_t file;
	file = H5Fopen(*(argv+1), H5F_ACC_RDONLY, H5P_DEFAULT);
	H5Fclose(file);
]),
  AC_MSG_RESULT(found),
  AC_MSG_FAILURE(failed!))
LIBS="$SAVE"
])
